package com.example.takeawaysystemserver.service;

import com.example.takeawaysystemserver.entity.User;
import com.baomidou.mybatisplus.extension.service.IService;
import com.example.takeawaysystemserver.model.dto.UserLoginDTO;
import com.example.takeawaysystemserver.model.dto.UserPasswordDTO;
import com.example.takeawaysystemserver.model.dto.UserRegisterDTO;
import com.example.takeawaysystemserver.model.dto.UserUpdateDTO;
import com.example.takeawaysystemserver.util.R;

/**
* @author qiushengyu
* @description 针对表【user】的数据库操作Service
* @createDate 2024-07-11 17:14:00
*/
public interface UserService extends IService<User> {
    /**
     * 用户注册
     * @param userRegisterDTO 注册类DTO
     * @return 注册信息
     */
    R<String> register(UserRegisterDTO userRegisterDTO);

    /**
     * 用户登录
     * @param userLoginDTO 登录类DTO
     * @return 登录信息
     */
    R<String> login(UserLoginDTO userLoginDTO);

    /**
     * 登出
     * @param token 用户token
     * @return 登出信息
     */
    R<String> logout(String token);

    /**
     * 修改用户信息
     * @param userUpdateDTO 修改类DTO
     * @return 修改信息
     */
    R<String> updateUserInfo(String token, UserUpdateDTO userUpdateDTO);

    /**
     * 修改用户密码
     * @param token 用户token
     * @param userPasswordDTO 密码类DTO
     * @return 修改信息
     */
    R<String> updatePassword(String token, UserPasswordDTO userPasswordDTO);

    /**
     * 修改用户地址信息
     * @param token 用户token
     * @param address 新地址
     * @return 修改信息
     */
    R<String> updateAddress(String token, String address);
}
